"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const wechat_1 = __importDefault(require("../lib/wechat"));
const article_1 = require("../models/article");
const media_1 = require("../models/media");
(0, vitest_1.describe)('Wechat Article API', function () {
    (0, vitest_1.it)('expect work with <img> and barckground-image', async () => {
        const wechat = new wechat_1.default(process.env.APP_ID || '', process.env.APP_SECRET || '');
        await article_1.Article.init({ wechat });
        await media_1.Media.init({
            wechat,
            modelName: 'media'
        });
        const content = `
      <img src="https://shanyue.tech/wechat.jpeg">
      <span style="background-image: url(https://img.alicdn.com/tfs/TB1Yycwyrj1gK0jSZFuXXcrHpXa-32-32.png); display: inline-block; width: 18px; height: 18px; background-size: 18px; background-repeat: no-repeat; background-position: center">
    `;
        const media = await media_1.Media.create({
            src: 'https://shanyue.tech/wechat.jpeg',
            type: 'image'
        });
        const data = await article_1.Article.create({
            thumbMediaId: media.media_id,
            title: 'Hello, world',
            author: 'shanyue',
            showCoverPic: 0,
            content
        });
        (0, vitest_1.expect)(data.media_id).length.to.gt(10);
    });
    (0, vitest_1.it)('expect automatic inspection of the content type', async () => {
        const wechat = new wechat_1.default(process.env.APP_ID || '', process.env.APP_SECRET || '');
        await article_1.Article.init({ wechat });
        await media_1.Media.init({
            wechat,
            modelName: 'media'
        });
        const content = `
      <img src="https://static.shanyue.tech/images/24-04-12/clipboard-7240.681f82.webp">
    `;
        const media = await media_1.Media.create({
            src: 'https://shanyue.tech/wechat.jpeg',
            type: 'image'
        });
        const data = await article_1.Article.create({
            thumbMediaId: media.media_id,
            title: 'expect automatic inspection of the content type',
            author: 'shanyue',
            showCoverPic: 0,
            content
        });
        (0, vitest_1.expect)(data.media_id).length.to.gt(10);
    });
    (0, vitest_1.it)('expect work with unsported image type (svg、webp)', async () => {
        const wechat = new wechat_1.default(process.env.APP_ID || '', process.env.APP_SECRET || '');
        await article_1.Article.init({ wechat });
        await media_1.Media.init({
            wechat,
            modelName: 'media'
        });
        const content = `
      <img src="https://shanyue.tech/wechat.jpeg">
      <img src="https://markdown.devtool.tech/icon.svg">
    `;
        const media = await media_1.Media.create({
            src: 'https://shanyue.tech/wechat.jpeg',
            type: 'image'
        });
        const data = await article_1.Article.create({
            thumbMediaId: media.media_id,
            title: 'Hello, world',
            author: 'shanyue',
            showCoverPic: 0,
            content
        });
        (0, vitest_1.expect)(data.media_id).length.to.gt(10);
    });
});
